==> controlpyweb-0.0.12-py3-none-any.whl: tests/test_webio.py <==
from unittest import mock

from controlpyweb.errors import ControlPyWebAddressNotFoundError
from controlpyweb.single_io import DiscreteIn, DiscreteOut, AnalogOut
from controlpyweb.webio_module import WebIOModule
from assertpy import assert_that
import unittest
import json


incoming = '''
    {
    "vin":"23.6",
    "register1":"0",
    "device1DigitalInput1":"1",
    "device1DigitalInput2":"0",
    "device1DigitalInput3":"0",
    "device1DigitalInput4":"0",
    "device1DigitalInput5":"0",
    "device1DigitalInput6":"0",
    "device1DigitalInput7":"0",
    "device1DigitalInput8":"0",
    "redLamp":"1",
    "amberLamp":"1",
    "greenLamp":"0",
    "flashLamp":"0",
    "allowStart":"0",
    "device2Relay6":"0",
    "device2Relay7":"0",
    "device2Relay8":"0",
    "utcTime":"1559533814",
    "timezoneOffset":"-25200",
    "serialNumber":"00:0C:C8:04:24:B2",
    "temperature1":"87",
    "temperature2":"75"
    } 
'''


class Module(WebIOModule):
    Button1 = DiscreteIn("Button1", "device1DigitalInput1")
    Button2 = DiscreteIn("Button2", "device1DigitalInput2")
    Button3 = DiscreteIn("Button3", "device1DigitalInput3")
    Lamp1 = DiscreteOut("Lamp1", "redLamp")
    Lamp2 = DiscreteOut("Lamp2", "amberLamp")
    Temp1 = AnalogOut("Temp1", "temperature1")
    Temp2 = AnalogOut("Temp2", "temperature2")


module = Module("dummy url")


def mocked_requests_get(*args, **kwargs):
    class MockResponse:
        def __init__(self):
            pass
        def json(self):
            return json.loads(incoming)
    return MockResponse()


class TestWebIO(unittest.TestCase):

    def setUp(self):
        module.loads(incoming)
        self.incoming = json.loads(incoming)    # type: dict

    def test_can_read_common_properties(self):
        assert_that(module.serial_number).is_equal_to("00:0C:C8:04:24:B2")
        assert_that(module.vin).is_equal_to(23.6)
        assert_that(module.time_of_read.day).is_equal_to(2)

    def test_can_read_values(self):
        assert_that(module.Button1).is_true()
        assert_that(module.Button2).is_false()

    def test_can_write_values(self):
        module.Lamp1 = True
        assert_that(module.read("redLamp")).is_true()
        module.Lamp1 = False
        assert_that(module.read("redLamp")).is_false()

    def test_that_changes_are_captured(self):
        module.Lamp1 = not module.Lamp1
        module.Lamp2 = not module.Lamp2
        keys = module.changes
        assert_that(keys).contains('redLamp')
        assert_that(keys).contains('amberLamp')

    @mock.patch('requests.get', side_effect=mocked_requests_get)
    def test_that_can_read_values_from_hardware(self, mock_get):
        global incoming
        incoming = incoming.replace(':"0"', ':"1"')
        module.update_from_module()
        assert_that(module.Button1).is_true()
        assert_that(module.Button2).is_true()
        assert_that(module.Button3).is_true()

        incoming = incoming.replace(':"1"', ':"0"')
        module.update_from_module()
        assert_that(module.Button1).is_false()
        assert_that(module.Button2).is_false()
        assert_that(module.Button3).is_false()

    def test_that_trying_to_read_non_existing_register_gives_error(self):
        j = json.dumps(dict(dummy=False))
        module.loads(j)
        try:
            module.Button1 is True
            assert_that(True).is_false()
        except ControlPyWebAddressNotFoundError as ex:
            print(ex)

    def test_that_writing_duplicate_has_no_affect(self):
        module.Lamp1 = not Module.Lamp1
        changes = module.dumps(changes_only=True)
        assert_that(changes).is_not_empty()
        module.flush_changes()
        module.Lamp1 = module.Lamp1
        changes = module.dumps(changes_only=True)
        assert_that(changes).is_empty()

    def test_and_operator(self):
        module.Lamp1 = True
        module.Lamp2 = True
        assert_that(module.Lamp1 and module.Lamp2).is_true()

        module.Lamp2 = False
        assert_that(module.Lamp1 and module.Lamp2).is_false()

        assert_that(module.Lamp1 and True).is_true()
        assert_that(module.Lamp1 and False).is_false()

        assert_that(True and module.Lamp1).is_true()
        assert_that(False and module.Lamp1).is_false()

    def test_setting_one_equal_to_another(self):
        module.Lamp1 = True
        module.Lamp2 = False
        assert_that(module.Lamp1).is_not_equal_to(module.Lamp2)
        module.Lamp2 = Module.Lamp1
        assert_that(module.Lamp1).is_equal_to(module.Lamp2)

    def test_arithmatic_operations(self):
        module.Temp1 = 10.0
        module.Temp2 = 20.0

        assert_that(module.Temp1 + module.Temp2).is_equal_to(30)
        assert_that(module.Temp1 * module.Temp2).is_equal_to(200)
        assert_that(module.Temp2 / module.Temp1).is_equal_to(2)
        assert_that(module.Temp2 - module.Temp1).is_equal_to(10)

==> controlpyweb-0.0.14-py3-none-any.whl: tests/test_webio.py <==
from unittest import mock

from controlpyweb.errors import ControlPyWebAddressNotFoundError, WebIOConnectionError
from controlpyweb.single_io import DiscreteIn, DiscreteOut, AnalogOut
from controlpyweb.webio_module import WebIOModule
from assertpy import assert_that
import unittest
import json
from urllib3.exceptions import MaxRetryError, NewConnectionError
from requests.exceptions import ConnectionError


incoming = '''
    {
    "vin":"23.6",
    "register1":"0",
    "device1DigitalInput1":"1",
    "device1DigitalInput2":"0",
    "device1DigitalInput3":"0",
    "device1DigitalInput4":"0",
    "device1DigitalInput5":"0",
    "device1DigitalInput6":"0",
    "device1DigitalInput7":"0",
    "device1DigitalInput8":"0",
    "redLamp":"1",
    "amberLamp":"1",
    "greenLamp":"0",
    "flashLamp":"0",
    "allowStart":"0",
    "device2Relay6":"0",
    "device2Relay7":"0",
    "device2Relay8":"0",
    "utcTime":"1559533814",
    "timezoneOffset":"-25200",
    "serialNumber":"00:0C:C8:04:24:B2",
    "temperature1":"87",
    "temperature2":"75"
    } 
'''


class Module(WebIOModule):
    member_len = 7
    Button1 = DiscreteIn("Button1", "device1DigitalInput1", units="On/Off")
    Button2 = DiscreteIn("Button2", "device1DigitalInput2", units="Start/Stop")
    Button3 = DiscreteIn("Button3", "device1DigitalInput3")
    Lamp1 = DiscreteOut("Lamp1", "redLamp")
    Lamp2 = DiscreteOut("Lamp2", "amberLamp")
    Temp1 = AnalogOut("Temp1", "temperature1", units="DegF")
    Temp2 = AnalogOut("Temp2", "temperature2")


module = Module("testme")


def mocked_requests_get(*args, **kwargs):
    class MockResponse:
        def __init__(self):
            pass
        def json(self):
            return json.loads(incoming)
    return MockResponse()


class TestWebIO(unittest.TestCase):

    def setUp(self):
        module.loads(incoming)
        self.incoming = json.loads(incoming)    # type: dict

    def test_can_read_common_properties(self):
        assert_that(module.serial_number).is_equal_to("00:0C:C8:04:24:B2")
        assert_that(module.vin).is_equal_to(23.6)
        assert_that(module.time_of_read.day).is_equal_to(2)

    def test_can_read_values(self):
        assert_that(module.Button1).is_true()
        assert_that(module.Button2).is_false()

    def test_can_write_values(self):
        module.Lamp1 = True
        assert_that(module.read("redLamp")).is_true()
        module.Lamp1 = False
        assert_that(module.read("redLamp")).is_false()

    def test_that_changes_are_captured(self):
        module.Lamp1 = not module.Lamp1
        module.Lamp2 = not module.Lamp2
        keys = module.changes
        assert_that(keys).contains('redLamp')
        assert_that(keys).contains('amberLamp')

    @mock.patch('requests.get', side_effect=mocked_requests_get)
    def test_that_can_read_values_from_hardware(self, mock_get):
        global incoming
        incoming = incoming.replace(':"0"', ':"1"')
        module.update_from_module()
        assert_that(module.Button1).is_true()
        assert_that(module.Button2).is_true()
        assert_that(module.Button3).is_true()

        incoming = incoming.replace(':"1"', ':"0"')
        module.update_from_module()
        assert_that(module.Button1).is_false()
        assert_that(module.Button2).is_false()
        assert_that(module.Button3).is_false()

    def test_that_trying_to_read_non_existing_register_gives_error(self):
        j = json.dumps(dict(dummy=False))
        module.loads(j)
        try:
            module.Button1 is True
            assert_that(True).is_false()
        except ControlPyWebAddressNotFoundError as ex:
            print(ex)

    def test_that_writing_duplicate_has_no_affect(self):
        module.Lamp1 = not Module.Lamp1
        changes = module.dumps(changes_only=True)
        assert_that(changes).is_not_empty()
        module.flush_changes()
        module.Lamp1 = module.Lamp1
        changes = module.dumps(changes_only=True)
        assert_that(changes).is_empty()

    def test_and_operator(self):
        module.Lamp1 = True
        module.Lamp2 = True
        assert_that(module.Lamp1 and module.Lamp2).is_true()

        module.Lamp2 = False
        assert_that(module.Lamp1 and module.Lamp2).is_false()

        assert_that(module.Lamp1 and True).is_true()
        assert_that(module.Lamp1 and False).is_false()

        assert_that(True and module.Lamp1).is_true()
        assert_that(False and module.Lamp1).is_false()

    def test_setting_one_equal_to_another(self):
        module.Lamp1 = True
        module.Lamp2 = False
        assert_that(module.Lamp1).is_not_equal_to(module.Lamp2)
        module.Lamp2 = Module.Lamp1
        assert_that(module.Lamp1).is_equal_to(module.Lamp2)

    def test_arithmetic_operations(self):
        module.Temp1 = 10.0
        module.Temp2 = 20.0

        assert_that(module.Temp1 + module.Temp2).is_equal_to(30)
        assert_that(module.Temp1 * module.Temp2).is_equal_to(200)
        assert_that(module.Temp2 / module.Temp1).is_equal_to(2)
        assert_that(module.Temp2 - module.Temp1).is_equal_to(10)

    def test_should_be_able_to_read_units(self):
        assert_that(module.Button1.units).is_equal_to("On/Off")
        assert_that(module.Temp1.units).is_equal_to("DegF")

    def test_can_get_members_list(self):
        assert_that(len(module.members)).is_equal_to(module.member_len)

    def test_module_creates_correct_json(self):
        j = module.dumps()
        print(j)

    def test_connection_error(self):
        try:
            module.update_from_module(timeout=0.00001)
        except WebIOConnectionError as ex:
            pass
